export declare const DEFAULT_COL = "path";
export declare type Path = string[];
export interface IContentRow {
    path: Path;
    kind: string;
    getChildren?: () => Promise<IContentRow[]>;
}
interface IContentDirRow {
    path: Path;
    kind: "dir";
    getChildren: () => Promise<IContentRow[]>;
}
export declare class Content<T extends IContentRow> {
    constructor(row: T);
    close(): void;
    expand(): Promise<void>;
    getChildren(): Promise<Content<T>[] | undefined>;
    getPathAtDepth(depth?: number, fill?: string): any[];
    getTree(_flat?: Content<T>[]): Promise<Content<T>[]>;
    invalidate(): void;
    /**
     * returns the raw children array fetched by getChildren
     */
    get cache(): Content<T>[] | undefined;
    get isExpand(): boolean;
    get nchildren(): number;
    get name(): string;
    /**
     * like cache but filtered, sorted, etc
     */
    get view(): Content<T>[] | undefined;
    protected get _dirty(): boolean;
    set filterer(filterer: Content.Filterer<T> | undefined);
    set sorter(sorter: Content.Sorter<T> | undefined);
    readonly isDir: boolean;
    readonly row: T;
    protected _isExpand: boolean;
    protected _cache?: Content<T>[];
    protected _view?: Content<T>[];
    protected _viewTree?: Content<T>[];
    protected _dirtyChildren: boolean;
    protected _dirtyFilter: boolean;
    protected _dirtySort: boolean;
    protected _filterer?: Content.Filterer<T>;
    protected _sorter?: Content.Sorter<T>;
}
export declare namespace Content {
    type Filterer<T extends IContentRow> = (c: Content<T>) => boolean;
    type Sorter<T extends IContentRow> = (l: Content<T>, r: Content<T>) => number;
    function isContentDirRow<T extends IContentRow, U extends IContentDirRow>(x: T | U): x is U;
}
export {};
