/*
 * Copyright (c) 2020, Max Klein
 *
 * This file is part of the tree-finder library, distributed under the terms of
 * the BSD 3 Clause license. The full license can be found in the LICENSE file.
 */
export const DEFAULT_COL = "path";
export class Content {
    constructor(row) {
        this._isExpand = false;
        this._dirtyChildren = true;
        this._dirtyFilter = true;
        this._dirtySort = true;
        this.isDir = row.kind === "dir";
        this.row = row;
    }
    close() {
        this._isExpand = false;
    }
    async expand() {
        await this.getChildren();
        this._isExpand = true;
    }
    async getChildren() {
        var _a, _b, _c;
        if (!Content.isContentDirRow(this.row)) {
            return;
        }
        if (!this._dirty) {
            return this._cache;
        }
        if (this._dirtyChildren) {
            this._cache = (_a = (await this.row.getChildren()).map((c) => new Content(c))) !== null && _a !== void 0 ? _a : [];
            this._dirtyChildren = false;
            this._dirtyFilter = true;
            this._dirtySort = true;
        }
        if (this._dirtyFilter && this._filterer) {
            this._view = (_b = this._cache) === null || _b === void 0 ? void 0 : _b.filter(this._filterer);
            this._dirtyFilter = false;
        }
        if (this._dirtySort && this._sorter) {
            this._view = (_c = this.view) === null || _c === void 0 ? void 0 : _c.sort(this._sorter);
            this._dirtySort = false;
        }
        return this.view;
        // return this._children?.values();
    }
    getPathAtDepth(depth = 0, fill) {
        const pth = this.row.path.slice(depth);
        if (fill !== undefined && pth.length > 1) {
            return [...Array(pth.length - 1).fill(fill), pth[pth.length - 1]];
        }
        else {
            return pth;
        }
    }
    async getTree(_flat = []) {
        var _a;
        if (this.isExpand) {
            for (const child of (_a = await this.getChildren()) !== null && _a !== void 0 ? _a : []) {
                if (child.isExpand) {
                    child.getTree(_flat);
                }
                _flat.push(child);
            }
        }
        return _flat;
    }
    invalidate() {
        [this._dirtyChildren, this._dirtyFilter, this._dirtySort] = [true, true, true];
    }
    /**
     * returns the raw children array fetched by getChildren
     */
    get cache() {
        return this._cache;
    }
    get isExpand() {
        return this._isExpand;
    }
    get nchildren() {
        var _a, _b;
        return (_b = (_a = this._cache) === null || _a === void 0 ? void 0 : _a.length) !== null && _b !== void 0 ? _b : 0;
        // return this._children?.size ?? 0;
    }
    get name() {
        return (this.row.path && this.row.path.length) ? this.row.path[this.row.path.length - 1] : "";
    }
    /**
     * like cache but filtered, sorted, etc
     */
    get view() {
        var _a;
        return (_a = this._view) !== null && _a !== void 0 ? _a : this._cache;
    }
    get _dirty() {
        return this._dirtyChildren || this._dirtyFilter || this._dirtySort;
    }
    set filterer(filterer) {
        this._filterer = filterer;
        this._dirtyFilter = true;
    }
    set sorter(sorter) {
        this._sorter = sorter;
        this._dirtySort = true;
    }
}
(function (Content) {
    function isContentDirRow(x) {
        return x.kind === "dir";
    }
    Content.isContentDirRow = isContentDirRow;
})(Content || (Content = {}));
//# sourceMappingURL=content.js.map