import { Tag, Tree } from "../util";
import "../../style/breadcrumbs";
export class TreeFinderBreadcrumbsElement extends HTMLElement {
    constructor() {
        super(...arguments);
        this._initialized = false;
        this._initializedListeners = false;
    }
    connectedCallback() {
        if (!this._initialized) {
            this.create_shadow_dom();
            this._initialized = true;
        }
        if (!this._initializedListeners) {
            this.addEventListener("mouseup", event => this.onClick(event));
            this._initializedListeners = true;
        }
    }
    init(model) {
        this.model = model;
        this.model.crumbs.crumbNamesSub.subscribe({
            next: x => this._onCrumbUpdate(x),
        });
    }
    async _onCrumbUpdate(path) {
        this.innerHTML = Tree.breadcrumbsSpans(path);
    }
    create_shadow_dom() {
        this.attachShadow({ mode: "open" });
        const crumbsSlot = `<slot></slot>`;
        this.shadowRoot.innerHTML = Tag.html `
      <style>
        .tf-breadcrumbs-top {
          display: flex;
          align-items: flex-start;
        }
      </style>
      <div class="tf-breadcrumbs-top">
        ${crumbsSlot}
      </div>
    `;
        [this.shadowSheet, this.top] = this.shadowRoot.children;
    }
    async onClick(event) {
        if (event.button !== 0) {
            return;
        }
        const target = event.target;
        if (target.dataset.crumbix) {
            this.model.crumbs.revert(parseInt(target.dataset.crumbix));
        }
    }
}
(function (TreeFinderBreadcrumbsElement) {
    function get() {
        if (document.createElement("tree-finder-breadcrumbs").constructor === HTMLElement) {
            customElements.define("tree-finder-breadcrumbs", TreeFinderBreadcrumbsElement);
        }
        return customElements.get('tree-finder-breadcrumbs');
    }
    TreeFinderBreadcrumbsElement.get = get;
})(TreeFinderBreadcrumbsElement || (TreeFinderBreadcrumbsElement = {}));
TreeFinderBreadcrumbsElement.get();
//# sourceMappingURL=breadcrumbs.js.map