import { Tag } from "../util";
import "../../style/filter";
export class TreeFinderFilterElement extends HTMLElement {
    constructor() {
        super(...arguments);
        this._initialized = false;
        this._initializedListeners = false;
    }
    clear() {
        this.innerHTML = `<input class="tf-filter-input"></input>`;
        [this._input] = this.children;
    }
    connectedCallback() {
        if (!this._initialized) {
            this.create_shadow_dom();
            this._initialized = true;
        }
        if (!this._initializedListeners) {
            this.addEventListener("input", event => this.onInput(event));
            this._initializedListeners = true;
        }
    }
    init(model, ix = 0) {
        this.model = model;
        this.clear();
        if (ix === 0) {
            this.col = "path";
        }
        else {
            this.col = this.model.columns[ix - 1];
        }
    }
    create_shadow_dom() {
        this.attachShadow({ mode: "open" });
        const inputSlot = `<slot></slot>`;
        this.shadowRoot.innerHTML = Tag.html `
      <style>
        :host > .tf-filter-top {
          display: inline-block;
          padding: 8px 0px 4px 0px;
        }
      </style>
      <div class="tf-filter-top">
        ${inputSlot}
      </div>
    `;
        [this.shadowSheet, this.top] = this.shadowRoot.children;
    }
    onInput(event) {
        const fpat = { col: this.col, pattern: event.target.value };
        this.model.onFilterInput(fpat);
    }
    get input() {
        return this._input;
    }
}
(function (TreeFinderFilterElement) {
    function get() {
        if (document.createElement("tree-finder-filter").constructor === HTMLElement) {
            customElements.define("tree-finder-filter", TreeFinderFilterElement);
        }
        return customElements.get('tree-finder-filter');
    }
    TreeFinderFilterElement.get = get;
})(TreeFinderFilterElement || (TreeFinderFilterElement = {}));
TreeFinderFilterElement.get();
//# sourceMappingURL=filter.js.map