import { Content, IContentRow } from "./content";
declare const SORT_ORDERS: readonly ["asc", "desc", null];
export declare type SortOrder = typeof SORT_ORDERS[number];
interface IFilterPattern<T extends IContentRow> {
    col: keyof T;
    pattern: string;
}
export declare class FilterPatterns<T extends IContentRow> {
    constructor(patterns?: IFilterPattern<T>[]);
    set(fpat: IFilterPattern<T>): void;
    get any(): boolean;
    get patterns(): { [k in keyof T]: string; };
    protected _patterns: {
        [k in keyof T]: string;
    };
}
interface ISortState<T extends IContentRow> {
    col: keyof T;
    order: SortOrder;
}
interface ISortStateFull<T extends IContentRow> extends ISortState<T> {
    sign: -1 | 1;
    ix: number;
}
export declare class SortStates<T extends IContentRow> {
    readonly defaultColumn = "path";
    constructor(states?: ISortState<T>[]);
    readonly byColumn: {
        [k in keyof T]: ISortStateFull<T>;
    };
    readonly states: ISortStateFull<T>[];
}
export declare function filterContentRoot<T extends IContentRow>({ root, filterPatterns, pathDepth }: {
    root: Content<T>;
    filterPatterns: FilterPatterns<T>;
    pathDepth?: number;
}): Promise<Content<T>[]>;
export declare function filterSortContentRoot<T extends IContentRow>({ root, filterPatterns, sortStates, col, multisort, pathDepth }: {
    root: Content<T>;
    filterPatterns: FilterPatterns<T>;
    sortStates: SortStates<T>;
    col?: keyof T;
    multisort?: boolean;
    pathDepth?: number;
}): Promise<[Content<T>[], SortStates<T>]>;
export declare function sortContentRoot<T extends IContentRow>({ root, sortStates, col, multisort }: {
    root: Content<T>;
    sortStates: SortStates<T>;
    col?: keyof T;
    multisort?: boolean;
}): Promise<[Content<T>[], SortStates<T>]>;
export {};
