import { BehaviorSubject } from "rxjs";
import { Content, IContentRow } from "./content";
import { FilterPatterns, SortStates } from "./filtersort";
declare class CrumbModel<T extends IContentRow> {
    constructor();
    revert(crumbIx: number): T | undefined;
    extend(crumbs: T[]): T;
    protected _onCrumbUpdate(): Promise<void>;
    readonly crumbNamesSub: BehaviorSubject<string[]>;
    readonly revertedCrumbSub: BehaviorSubject<T | undefined>;
    protected _crumbsRows: T[];
}
export declare class ContentsModel<T extends IContentRow> {
    constructor(root: T, options?: Partial<ContentsModel.IOptions<T>>);
    open(root: T): Promise<void>;
    initColumns(): void;
    collapse(rix: number): Promise<void>;
    expand(rix: number): Promise<void>;
    filter(props?: {
        autosize?: boolean;
    }): Promise<void>;
    onFilterInput(fpat: {
        col: keyof T;
        pattern: string;
    }): void;
    requestDraw(autosize?: boolean): void;
    sort(props?: {
        col?: keyof T;
        multisort?: boolean;
        autosize?: boolean;
    }): Promise<void>;
    get columns(): (keyof T)[];
    get contents(): Content<T>[];
    get filterPatterns(): FilterPatterns<T>;
    get pathDepth(): number;
    get sortStates(): SortStates<T>;
    get root(): Content<T>;
    get options(): Partial<ContentsModel.IOptions<T>>;
    set options(options: Partial<ContentsModel.IOptions<T>>);
    get ixByColumn(): { [k in keyof T]: number; };
    readonly columnWidthsSub: BehaviorSubject<string[]>;
    readonly crumbs: CrumbModel<T>;
    readonly drawSub: BehaviorSubject<boolean>;
    readonly selection: SelectionModel<IContentRow>;
    protected _columns: (keyof T)[];
    protected _contents: Content<T>[];
    protected _filterContents: Content<T>[];
    protected _filterPatterns: FilterPatterns<T>;
    protected _parentMap: ContentsModel.RefMap<T>;
    protected _root: Content<T>;
    protected _sortStates: SortStates<T>;
    protected _options: ContentsModel.IOptions<T>;
    private _ixByColumn;
}
export declare namespace ContentsModel {
    interface IOptions<T extends IContentRow> {
        /**
         * optionally specify the visible columns, and the order they appear in
         */
        columnNames: (keyof T)[];
        /**
         * if true, always (re)fetch children when opening a dir
         */
        doRefetch: boolean;
    }
    type RefMap<T extends IContentRow> = WeakMap<T, T>;
}
export declare class SelectionModel<T extends IContentRow> {
    constructor();
    clear(): void;
    get(contents: Content<T>[]): Content<T>[];
    has(content: Content<T>): boolean;
    select(content: Content<T>, add?: boolean): void;
    selectRange(end: Content<T>, contents: Content<T>[]): void;
    protected range: string[];
    protected pivot: string | null;
    protected selection: Set<string>;
}
export declare namespace SelectionModel {
    function findRange(start: string | null, end: string, vals: string[]): string[];
}
export {};
