export var RegularTable;
(function (RegularTable) {
    const TOP_LEVEL_TAGNAME = "TREE-FINDER";
    /*
     * click-related functions
     */
    function cellClicked(metadata) {
        return typeof (metadata === null || metadata === void 0 ? void 0 : metadata.y) !== "undefined" && !(metadata === null || metadata === void 0 ? void 0 : metadata.column_header_y);
    }
    RegularTable.cellClicked = cellClicked;
    function columnHeaderClicked(metadata) {
        var _a;
        return typeof ((_a = metadata) === null || _a === void 0 ? void 0 : _a.column_header_y) !== "undefined" && !!(metadata === null || metadata === void 0 ? void 0 : metadata.column_header);
    }
    RegularTable.columnHeaderClicked = columnHeaderClicked;
    function rowClicked(metadata) {
        return cellClicked(metadata) || rowHeaderClicked(metadata);
    }
    RegularTable.rowClicked = rowClicked;
    function rowHeaderClicked(metadata) {
        var _a;
        return typeof ((_a = metadata) === null || _a === void 0 ? void 0 : _a.row_header_x) !== "undefined" && !!(metadata === null || metadata === void 0 ? void 0 : metadata.row_header);
    }
    RegularTable.rowHeaderClicked = rowHeaderClicked;
    /*
     * debug utils
     */
    function clickLoggingListener(event, rt) {
        const metadata = metadataFromElement(event.target, rt, true);
        if (!metadata) {
            console.log(`event has no metadata`);
            return;
        }
        if (cellClicked(metadata)) {
            console.log(`cell clicked`);
        }
        if (columnHeaderClicked(metadata)) {
            console.log(`column header clicked`);
        }
        if (rowClicked(metadata)) {
            console.log(`row clicked`);
        }
        if (rowHeaderClicked(metadata)) {
            console.log(`row header clicked`);
        }
        console.log(metadata);
    }
    RegularTable.clickLoggingListener = clickLoggingListener;
    /*
     * general metadata-related functions
     */
    function metadataFromElement(target, rt, recursive = true) {
        if (target.tagName === TOP_LEVEL_TAGNAME) {
            return;
        }
        let metadata = rt.getMeta(target);
        if (!recursive || metadata || !target.parentElement) {
            return metadata;
        }
        return metadataFromElement(target.parentElement, rt, recursive);
    }
    RegularTable.metadataFromElement = metadataFromElement;
})(RegularTable || (RegularTable = {}));
export var String;
(function (String) {
    /**
     * remove all back/slashes from string
     */
    function trimSlash(x) {
        return x.replace(/[\/\\]/g, "");
    }
    String.trimSlash = trimSlash;
    /**
     * remove all back/slashes, then add a trailing slash if requested to a string
     */
    function normSlash(x, trailing) {
        return String.trimSlash(x) + (trailing ? "/" : "");
    }
    String.normSlash = normSlash;
})(String || (String = {}));
export var Tag;
(function (Tag) {
    Tag.html = (strings, ...args) => strings
        .map((str, i) => [str, args[i]])
        .flat()
        .filter((a) => !!a)
        .join("");
})(Tag || (Tag = {}));
export var Tree;
(function (Tree) {
    const treeTemplate = document.createElement("template");
    function rowHeaderLevelsHtml({ isDir, isOpen, path = [] }) {
        const tree_levels = path.slice(1).map(() => '<span class="rt-tree-group"></span>');
        if (isDir) {
            const group_icon = isOpen ? "remove" : "add";
            const tree_button = `<span class="rt-row-header-icon">${group_icon}</span>`;
            tree_levels.push(tree_button);
        }
        return tree_levels.join("");
    }
    function rowHeaderSpan({ isDir, isOpen, path, pathRender = "tree" }) {
        path = path.map((x, ix) => String.normSlash(x, ix < (path.length - 1) ? true : isDir));
        const header_classes = !isDir ? "rt-group-name rt-group-leaf" : "rt-group-name";
        const header_text = pathRender === "relative" ? path.join("") : path.slice(-1).join("");
        const tree_levels = rowHeaderLevelsHtml({ isDir, isOpen, path: pathRender === "tree" ? path : [] });
        treeTemplate.innerHTML = `<span class="rt-tree-container">${tree_levels}<span class="${header_classes}">${header_text}</span></span>`;
        if (pathRender === "regular") {
            return [path.slice(0, -1).join(""), treeTemplate.content.firstChild];
        }
        else {
            return [treeTemplate.content.firstChild];
        }
    }
    Tree.rowHeaderSpan = rowHeaderSpan;
    function breadcrumbsSpans(path) {
        return `<div class="tf-breadcrumbs-home"><span class="tf-breadcrumbs-crumb tf-breadcrumbs-icon tf-breadcrumbs-dir-icon" data-crumbix="0">""</span><span>/</span></div>` + ([...path.slice(1),]
            .map((x, i) => `<span class="tf-breadcrumbs-crumb" data-crumbix="${i + 1}">${x}</span>`)
            .join(`<span class="tf-breadcrumbs-separator">/</span>`));
    }
    Tree.breadcrumbsSpans = breadcrumbsSpans;
})(Tree || (Tree = {}));
//# sourceMappingURL=util.js.map